==> catbuffer-0.1.2.20210302.114727a1-py3-none-any.whl: symbol_catbuffer/DifficultyDto.py <==
#!/usr/bin/python
"""
    Copyright (c) 2016-2019, Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp.
    Copyright (c) 2020-present, Jaguar0625, gimre, BloodyRookie.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
"""

# pylint: disable=W0622,W0612,C0301,R0904

from __future__ import annotations
from .GeneratorUtils import GeneratorUtils


class DifficultyDto:
    """Difficulty.

    Attributes:
        difficulty: Difficulty.
    """

    def __init__(self, difficulty: int):
        """Constructor.

        Args:
            difficulty: Difficulty.
        """
        self.difficulty = difficulty

    @classmethod
    def loadFromBinary(cls, payload: bytes) -> DifficultyDto:
        """Creates an instance of DifficultyDto from binary payload.

        Args:
            payload: Byte payload to use to serialize the object.
        Returns:
            Instance of DifficultyDto.
        """
        bytes_ = bytes(payload)
        difficulty = GeneratorUtils.bufferToUint(GeneratorUtils.getBytes(bytes_, 8))
        return DifficultyDto(difficulty)

    @classmethod
    def getSize(cls) -> int:
        """Gets the size of the object.
        Returns:
            Size in bytes.
        """
        return 8

    def getDifficulty(self) -> int:
        """Gets Difficulty.

        Returns:
            Difficulty.
        """
        return self.difficulty

    def serialize(self) -> bytes:
        """Serializes self to bytes.

        Returns:
            Serialized bytes.
        """
        bytes_ = bytes()
        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(self.getDifficulty(), 8))
        return bytes_

==> catbuffer-0.1.2.20210302.135454a1-py3-none-any.whl: symbol_catbuffer/DifficultyDto.py <==
#!/usr/bin/python
"""
    Copyright (c) 2016-2019, Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp.
    Copyright (c) 2020-present, Jaguar0625, gimre, BloodyRookie.

    This file is part of Catapult.

    Catapult is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    Catapult is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with Catapult. If not, see <http://www.gnu.org/licenses/>.
"""

# pylint: disable=W0622,W0612,C0301,R0904

from __future__ import annotations
from .GeneratorUtils import GeneratorUtils


class DifficultyDto:
    """Difficulty.

    Attributes:
        difficulty: Difficulty.
    """
    def __init__(self, difficulty: int = 0):
        """Constructor.

        Args:
            difficulty: Difficulty.
        """
        self.difficulty = difficulty

    @classmethod
    def loadFromBinary(cls, payload: bytes) -> DifficultyDto:
        """Creates an instance of DifficultyDto from binary payload.

        Args:
            payload: Byte payload to use to serialize the object.
        Returns:
            Instance of DifficultyDto.
        """
        bytes_ = bytes(payload)
        difficulty = GeneratorUtils.bufferToUint(GeneratorUtils.getBytes(bytes_, 8))
        return DifficultyDto(difficulty)

    @classmethod
    def getSize(cls) -> int:
        """Gets the size of the object.
        Returns:
            Size in bytes.
        """
        return 8

    def getDifficulty(self) -> int:
        """Gets Difficulty.

        Returns:
            Difficulty.
        """
        return self.difficulty

    def serialize(self) -> bytes:
        """Serializes self to bytes.

        Returns:
            Serialized bytes.
        """
        bytes_ = bytes()
        bytes_ = GeneratorUtils.concatTypedArrays(bytes_, GeneratorUtils.uintToBuffer(self.getDifficulty(), 8))
        return bytes_
